Paydunya class Facturation
Constructors
- Paydunya({required dynamic keysApi})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
createChekoutInvoice(
{required Billing billing}) → Future< CheckoutInvoice> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
pay(
{required PayerInfo payerInfo, required PaymentMethod paymentMethod}) → Future< ResponseSoftPay> -
toString(
) → String -
A string representation of this object.
inherited
-
verifyStatePayment(
{required String invoiceToken}) → Future< StatusPayment>
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited